.term-bg-color-0 { background-color: #2e3436; }
.term-fg-color-0 { color: #2e3436; }
.term-bg-color-1 { background-color: #cc0000; }
.term-fg-color-1 { color: #cc0000; }
.term-bg-color-2 { background-color: #4e9a06; }
.term-fg-color-2 { color: #4e9a06; }
.term-bg-color-3 { background-color: #c4a000; }
.term-fg-color-3 { color: #c4a000; }
.term-bg-color-4 { background-color: #3465a4; }
.term-fg-color-4 { color: #3465a4; }
.term-bg-color-5 { background-color: #75507b; }
.term-fg-color-5 { color: #75507b; }
.term-bg-color-6 { background-color: #06989a; }
.term-fg-color-6 { color: #06989a; }
.term-bg-color-7 { background-color: #d3d7cf; }
.term-fg-color-7 { color: #d3d7cf; }
.term-bg-color-8 { background-color: #555753; }
.term-fg-color-8 { color: #555753; }
.term-bg-color-9 { background-color: #ef2929; }
.term-fg-color-9 { color: #ef2929; }
.term-bg-color-10 { background-color: #8ae234; }
.term-fg-color-10 { color: #8ae234; }
.term-bg-color-11 { background-color: #fce94f; }
.term-fg-color-11 { color: #fce94f; }
.term-bg-color-12 { background-color: #729fcf; }
.term-fg-color-12 { color: #729fcf; }
.term-bg-color-13 { background-color: #ad7fa8; }
.term-fg-color-13 { color: #ad7fa8; }
.term-bg-color-14 { background-color: #34e2e2; }
.term-fg-color-14 { color: #34e2e2; }
.term-bg-color-15 { background-color: #eeeeec; }
.term-fg-color-15 { color: #eeeeec; }
.term-bg-color-16 { background-color: #000000; }
.term-fg-color-16 { color: #000000; }
.term-bg-color-17 { background-color: #00005f; }
.term-fg-color-17 { color: #00005f; }
.term-bg-color-18 { background-color: #000087; }
.term-fg-color-18 { color: #000087; }
.term-bg-color-19 { background-color: #0000af; }
.term-fg-color-19 { color: #0000af; }
.term-bg-color-20 { background-color: #0000d7; }
.term-fg-color-20 { color: #0000d7; }
.term-bg-color-21 { background-color: #0000ff; }
.term-fg-color-21 { color: #0000ff; }
.term-bg-color-22 { background-color: #005f00; }
.term-fg-color-22 { color: #005f00; }
.term-bg-color-23 { background-color: #005f5f; }
.term-fg-color-23 { color: #005f5f; }
.term-bg-color-24 { background-color: #005f87; }
.term-fg-color-24 { color: #005f87; }
.term-bg-color-25 { background-color: #005faf; }
.term-fg-color-25 { color: #005faf; }
.term-bg-color-26 { background-color: #005fd7; }
.term-fg-color-26 { color: #005fd7; }
.term-bg-color-27 { background-color: #005fff; }
.term-fg-color-27 { color: #005fff; }
.term-bg-color-28 { background-color: #008700; }
.term-fg-color-28 { color: #008700; }
.term-bg-color-29 { background-color: #00875f; }
.term-fg-color-29 { color: #00875f; }
.term-bg-color-30 { background-color: #008787; }
.term-fg-color-30 { color: #008787; }
.term-bg-color-31 { background-color: #0087af; }
.term-fg-color-31 { color: #0087af; }
.term-bg-color-32 { background-color: #0087d7; }
.term-fg-color-32 { color: #0087d7; }
.term-bg-color-33 { background-color: #0087ff; }
.term-fg-color-33 { color: #0087ff; }
.term-bg-color-34 { background-color: #00af00; }
.term-fg-color-34 { color: #00af00; }
.term-bg-color-35 { background-color: #00af5f; }
.term-fg-color-35 { color: #00af5f; }
.term-bg-color-36 { background-color: #00af87; }
.term-fg-color-36 { color: #00af87; }
.term-bg-color-37 { background-color: #00afaf; }
.term-fg-color-37 { color: #00afaf; }
.term-bg-color-38 { background-color: #00afd7; }
.term-fg-color-38 { color: #00afd7; }
.term-bg-color-39 { background-color: #00afff; }
.term-fg-color-39 { color: #00afff; }
.term-bg-color-40 { background-color: #00d700; }
.term-fg-color-40 { color: #00d700; }
.term-bg-color-41 { background-color: #00d75f; }
.term-fg-color-41 { color: #00d75f; }
.term-bg-color-42 { background-color: #00d787; }
.term-fg-color-42 { color: #00d787; }
.term-bg-color-43 { background-color: #00d7af; }
.term-fg-color-43 { color: #00d7af; }
.term-bg-color-44 { background-color: #00d7d7; }
.term-fg-color-44 { color: #00d7d7; }
.term-bg-color-45 { background-color: #00d7ff; }
.term-fg-color-45 { color: #00d7ff; }
.term-bg-color-46 { background-color: #00ff00; }
.term-fg-color-46 { color: #00ff00; }
.term-bg-color-47 { background-color: #00ff5f; }
.term-fg-color-47 { color: #00ff5f; }
.term-bg-color-48 { background-color: #00ff87; }
.term-fg-color-48 { color: #00ff87; }
.term-bg-color-49 { background-color: #00ffaf; }
.term-fg-color-49 { color: #00ffaf; }
.term-bg-color-50 { background-color: #00ffd7; }
.term-fg-color-50 { color: #00ffd7; }
.term-bg-color-51 { background-color: #00ffff; }
.term-fg-color-51 { color: #00ffff; }
.term-bg-color-52 { background-color: #5f0000; }
.term-fg-color-52 { color: #5f0000; }
.term-bg-color-53 { background-color: #5f005f; }
.term-fg-color-53 { color: #5f005f; }
.term-bg-color-54 { background-color: #5f0087; }
.term-fg-color-54 { color: #5f0087; }
.term-bg-color-55 { background-color: #5f00af; }
.term-fg-color-55 { color: #5f00af; }
.term-bg-color-56 { background-color: #5f00d7; }
.term-fg-color-56 { color: #5f00d7; }
.term-bg-color-57 { background-color: #5f00ff; }
.term-fg-color-57 { color: #5f00ff; }
.term-bg-color-58 { background-color: #5f5f00; }
.term-fg-color-58 { color: #5f5f00; }
.term-bg-color-59 { background-color: #5f5f5f; }
.term-fg-color-59 { color: #5f5f5f; }
.term-bg-color-60 { background-color: #5f5f87; }
.term-fg-color-60 { color: #5f5f87; }
.term-bg-color-61 { background-color: #5f5faf; }
.term-fg-color-61 { color: #5f5faf; }
.term-bg-color-62 { background-color: #5f5fd7; }
.term-fg-color-62 { color: #5f5fd7; }
.term-bg-color-63 { background-color: #5f5fff; }
.term-fg-color-63 { color: #5f5fff; }
.term-bg-color-64 { background-color: #5f8700; }
.term-fg-color-64 { color: #5f8700; }
.term-bg-color-65 { background-color: #5f875f; }
.term-fg-color-65 { color: #5f875f; }
.term-bg-color-66 { background-color: #5f8787; }
.term-fg-color-66 { color: #5f8787; }
.term-bg-color-67 { background-color: #5f87af; }
.term-fg-color-67 { color: #5f87af; }
.term-bg-color-68 { background-color: #5f87d7; }
.term-fg-color-68 { color: #5f87d7; }
.term-bg-color-69 { background-color: #5f87ff; }
.term-fg-color-69 { color: #5f87ff; }
.term-bg-color-70 { background-color: #5faf00; }
.term-fg-color-70 { color: #5faf00; }
.term-bg-color-71 { background-color: #5faf5f; }
.term-fg-color-71 { color: #5faf5f; }
.term-bg-color-72 { background-color: #5faf87; }
.term-fg-color-72 { color: #5faf87; }
.term-bg-color-73 { background-color: #5fafaf; }
.term-fg-color-73 { color: #5fafaf; }
.term-bg-color-74 { background-color: #5fafd7; }
.term-fg-color-74 { color: #5fafd7; }
.term-bg-color-75 { background-color: #5fafff; }
.term-fg-color-75 { color: #5fafff; }
.term-bg-color-76 { background-color: #5fd700; }
.term-fg-color-76 { color: #5fd700; }
.term-bg-color-77 { background-color: #5fd75f; }
.term-fg-color-77 { color: #5fd75f; }
.term-bg-color-78 { background-color: #5fd787; }
.term-fg-color-78 { color: #5fd787; }
.term-bg-color-79 { background-color: #5fd7af; }
.term-fg-color-79 { color: #5fd7af; }
.term-bg-color-80 { background-color: #5fd7d7; }
.term-fg-color-80 { color: #5fd7d7; }
.term-bg-color-81 { background-color: #5fd7ff; }
.term-fg-color-81 { color: #5fd7ff; }
.term-bg-color-82 { background-color: #5fff00; }
.term-fg-color-82 { color: #5fff00; }
.term-bg-color-83 { background-color: #5fff5f; }
.term-fg-color-83 { color: #5fff5f; }
.term-bg-color-84 { background-color: #5fff87; }
.term-fg-color-84 { color: #5fff87; }
.term-bg-color-85 { background-color: #5fffaf; }
.term-fg-color-85 { color: #5fffaf; }
.term-bg-color-86 { background-color: #5fffd7; }
.term-fg-color-86 { color: #5fffd7; }
.term-bg-color-87 { background-color: #5fffff; }
.term-fg-color-87 { color: #5fffff; }
.term-bg-color-88 { background-color: #870000; }
.term-fg-color-88 { color: #870000; }
.term-bg-color-89 { background-color: #87005f; }
.term-fg-color-89 { color: #87005f; }
.term-bg-color-90 { background-color: #870087; }
.term-fg-color-90 { color: #870087; }
.term-bg-color-91 { background-color: #8700af; }
.term-fg-color-91 { color: #8700af; }
.term-bg-color-92 { background-color: #8700d7; }
.term-fg-color-92 { color: #8700d7; }
.term-bg-color-93 { background-color: #8700ff; }
.term-fg-color-93 { color: #8700ff; }
.term-bg-color-94 { background-color: #875f00; }
.term-fg-color-94 { color: #875f00; }
.term-bg-color-95 { background-color: #875f5f; }
.term-fg-color-95 { color: #875f5f; }
.term-bg-color-96 { background-color: #875f87; }
.term-fg-color-96 { color: #875f87; }
.term-bg-color-97 { background-color: #875faf; }
.term-fg-color-97 { color: #875faf; }
.term-bg-color-98 { background-color: #875fd7; }
.term-fg-color-98 { color: #875fd7; }
.term-bg-color-99 { background-color: #875fff; }
.term-fg-color-99 { color: #875fff; }
.term-bg-color-100 { background-color: #878700; }
.term-fg-color-100 { color: #878700; }
.term-bg-color-101 { background-color: #87875f; }
.term-fg-color-101 { color: #87875f; }
.term-bg-color-102 { background-color: #878787; }
.term-fg-color-102 { color: #878787; }
.term-bg-color-103 { background-color: #8787af; }
.term-fg-color-103 { color: #8787af; }
.term-bg-color-104 { background-color: #8787d7; }
.term-fg-color-104 { color: #8787d7; }
.term-bg-color-105 { background-color: #8787ff; }
.term-fg-color-105 { color: #8787ff; }
.term-bg-color-106 { background-color: #87af00; }
.term-fg-color-106 { color: #87af00; }
.term-bg-color-107 { background-color: #87af5f; }
.term-fg-color-107 { color: #87af5f; }
.term-bg-color-108 { background-color: #87af87; }
.term-fg-color-108 { color: #87af87; }
.term-bg-color-109 { background-color: #87afaf; }
.term-fg-color-109 { color: #87afaf; }
.term-bg-color-110 { background-color: #87afd7; }
.term-fg-color-110 { color: #87afd7; }
.term-bg-color-111 { background-color: #87afff; }
.term-fg-color-111 { color: #87afff; }
.term-bg-color-112 { background-color: #87d700; }
.term-fg-color-112 { color: #87d700; }
.term-bg-color-113 { background-color: #87d75f; }
.term-fg-color-113 { color: #87d75f; }
.term-bg-color-114 { background-color: #87d787; }
.term-fg-color-114 { color: #87d787; }
.term-bg-color-115 { background-color: #87d7af; }
.term-fg-color-115 { color: #87d7af; }
.term-bg-color-116 { background-color: #87d7d7; }
.term-fg-color-116 { color: #87d7d7; }
.term-bg-color-117 { background-color: #87d7ff; }
.term-fg-color-117 { color: #87d7ff; }
.term-bg-color-118 { background-color: #87ff00; }
.term-fg-color-118 { color: #87ff00; }
.term-bg-color-119 { background-color: #87ff5f; }
.term-fg-color-119 { color: #87ff5f; }
.term-bg-color-120 { background-color: #87ff87; }
.term-fg-color-120 { color: #87ff87; }
.term-bg-color-121 { background-color: #87ffaf; }
.term-fg-color-121 { color: #87ffaf; }
.term-bg-color-122 { background-color: #87ffd7; }
.term-fg-color-122 { color: #87ffd7; }
.term-bg-color-123 { background-color: #87ffff; }
.term-fg-color-123 { color: #87ffff; }
.term-bg-color-124 { background-color: #af0000; }
.term-fg-color-124 { color: #af0000; }
.term-bg-color-125 { background-color: #af005f; }
.term-fg-color-125 { color: #af005f; }
.term-bg-color-126 { background-color: #af0087; }
.term-fg-color-126 { color: #af0087; }
.term-bg-color-127 { background-color: #af00af; }
.term-fg-color-127 { color: #af00af; }
.term-bg-color-128 { background-color: #af00d7; }
.term-fg-color-128 { color: #af00d7; }
.term-bg-color-129 { background-color: #af00ff; }
.term-fg-color-129 { color: #af00ff; }
.term-bg-color-130 { background-color: #af5f00; }
.term-fg-color-130 { color: #af5f00; }
.term-bg-color-131 { background-color: #af5f5f; }
.term-fg-color-131 { color: #af5f5f; }
.term-bg-color-132 { background-color: #af5f87; }
.term-fg-color-132 { color: #af5f87; }
.term-bg-color-133 { background-color: #af5faf; }
.term-fg-color-133 { color: #af5faf; }
.term-bg-color-134 { background-color: #af5fd7; }
.term-fg-color-134 { color: #af5fd7; }
.term-bg-color-135 { background-color: #af5fff; }
.term-fg-color-135 { color: #af5fff; }
.term-bg-color-136 { background-color: #af8700; }
.term-fg-color-136 { color: #af8700; }
.term-bg-color-137 { background-color: #af875f; }
.term-fg-color-137 { color: #af875f; }
.term-bg-color-138 { background-color: #af8787; }
.term-fg-color-138 { color: #af8787; }
.term-bg-color-139 { background-color: #af87af; }
.term-fg-color-139 { color: #af87af; }
.term-bg-color-140 { background-color: #af87d7; }
.term-fg-color-140 { color: #af87d7; }
.term-bg-color-141 { background-color: #af87ff; }
.term-fg-color-141 { color: #af87ff; }
.term-bg-color-142 { background-color: #afaf00; }
.term-fg-color-142 { color: #afaf00; }
.term-bg-color-143 { background-color: #afaf5f; }
.term-fg-color-143 { color: #afaf5f; }
.term-bg-color-144 { background-color: #afaf87; }
.term-fg-color-144 { color: #afaf87; }
.term-bg-color-145 { background-color: #afafaf; }
.term-fg-color-145 { color: #afafaf; }
.term-bg-color-146 { background-color: #afafd7; }
.term-fg-color-146 { color: #afafd7; }
.term-bg-color-147 { background-color: #afafff; }
.term-fg-color-147 { color: #afafff; }
.term-bg-color-148 { background-color: #afd700; }
.term-fg-color-148 { color: #afd700; }
.term-bg-color-149 { background-color: #afd75f; }
.term-fg-color-149 { color: #afd75f; }
.term-bg-color-150 { background-color: #afd787; }
.term-fg-color-150 { color: #afd787; }
.term-bg-color-151 { background-color: #afd7af; }
.term-fg-color-151 { color: #afd7af; }
.term-bg-color-152 { background-color: #afd7d7; }
.term-fg-color-152 { color: #afd7d7; }
.term-bg-color-153 { background-color: #afd7ff; }
.term-fg-color-153 { color: #afd7ff; }
.term-bg-color-154 { background-color: #afff00; }
.term-fg-color-154 { color: #afff00; }
.term-bg-color-155 { background-color: #afff5f; }
.term-fg-color-155 { color: #afff5f; }
.term-bg-color-156 { background-color: #afff87; }
.term-fg-color-156 { color: #afff87; }
.term-bg-color-157 { background-color: #afffaf; }
.term-fg-color-157 { color: #afffaf; }
.term-bg-color-158 { background-color: #afffd7; }
.term-fg-color-158 { color: #afffd7; }
.term-bg-color-159 { background-color: #afffff; }
.term-fg-color-159 { color: #afffff; }
.term-bg-color-160 { background-color: #d70000; }
.term-fg-color-160 { color: #d70000; }
.term-bg-color-161 { background-color: #d7005f; }
.term-fg-color-161 { color: #d7005f; }
.term-bg-color-162 { background-color: #d70087; }
.term-fg-color-162 { color: #d70087; }
.term-bg-color-163 { background-color: #d700af; }
.term-fg-color-163 { color: #d700af; }
.term-bg-color-164 { background-color: #d700d7; }
.term-fg-color-164 { color: #d700d7; }
.term-bg-color-165 { background-color: #d700ff; }
.term-fg-color-165 { color: #d700ff; }
.term-bg-color-166 { background-color: #d75f00; }
.term-fg-color-166 { color: #d75f00; }
.term-bg-color-167 { background-color: #d75f5f; }
.term-fg-color-167 { color: #d75f5f; }
.term-bg-color-168 { background-color: #d75f87; }
.term-fg-color-168 { color: #d75f87; }
.term-bg-color-169 { background-color: #d75faf; }
.term-fg-color-169 { color: #d75faf; }
.term-bg-color-170 { background-color: #d75fd7; }
.term-fg-color-170 { color: #d75fd7; }
.term-bg-color-171 { background-color: #d75fff; }
.term-fg-color-171 { color: #d75fff; }
.term-bg-color-172 { background-color: #d78700; }
.term-fg-color-172 { color: #d78700; }
.term-bg-color-173 { background-color: #d7875f; }
.term-fg-color-173 { color: #d7875f; }
.term-bg-color-174 { background-color: #d78787; }
.term-fg-color-174 { color: #d78787; }
.term-bg-color-175 { background-color: #d787af; }
.term-fg-color-175 { color: #d787af; }
.term-bg-color-176 { background-color: #d787d7; }
.term-fg-color-176 { color: #d787d7; }
.term-bg-color-177 { background-color: #d787ff; }
.term-fg-color-177 { color: #d787ff; }
.term-bg-color-178 { background-color: #d7af00; }
.term-fg-color-178 { color: #d7af00; }
.term-bg-color-179 { background-color: #d7af5f; }
.term-fg-color-179 { color: #d7af5f; }
.term-bg-color-180 { background-color: #d7af87; }
.term-fg-color-180 { color: #d7af87; }
.term-bg-color-181 { background-color: #d7afaf; }
.term-fg-color-181 { color: #d7afaf; }
.term-bg-color-182 { background-color: #d7afd7; }
.term-fg-color-182 { color: #d7afd7; }
.term-bg-color-183 { background-color: #d7afff; }
.term-fg-color-183 { color: #d7afff; }
.term-bg-color-184 { background-color: #d7d700; }
.term-fg-color-184 { color: #d7d700; }
.term-bg-color-185 { background-color: #d7d75f; }
.term-fg-color-185 { color: #d7d75f; }
.term-bg-color-186 { background-color: #d7d787; }
.term-fg-color-186 { color: #d7d787; }
.term-bg-color-187 { background-color: #d7d7af; }
.term-fg-color-187 { color: #d7d7af; }
.term-bg-color-188 { background-color: #d7d7d7; }
.term-fg-color-188 { color: #d7d7d7; }
.term-bg-color-189 { background-color: #d7d7ff; }
.term-fg-color-189 { color: #d7d7ff; }
.term-bg-color-190 { background-color: #d7ff00; }
.term-fg-color-190 { color: #d7ff00; }
.term-bg-color-191 { background-color: #d7ff5f; }
.term-fg-color-191 { color: #d7ff5f; }
.term-bg-color-192 { background-color: #d7ff87; }
.term-fg-color-192 { color: #d7ff87; }
.term-bg-color-193 { background-color: #d7ffaf; }
.term-fg-color-193 { color: #d7ffaf; }
.term-bg-color-194 { background-color: #d7ffd7; }
.term-fg-color-194 { color: #d7ffd7; }
.term-bg-color-195 { background-color: #d7ffff; }
.term-fg-color-195 { color: #d7ffff; }
.term-bg-color-196 { background-color: #ff0000; }
.term-fg-color-196 { color: #ff0000; }
.term-bg-color-197 { background-color: #ff005f; }
.term-fg-color-197 { color: #ff005f; }
.term-bg-color-198 { background-color: #ff0087; }
.term-fg-color-198 { color: #ff0087; }
.term-bg-color-199 { background-color: #ff00af; }
.term-fg-color-199 { color: #ff00af; }
.term-bg-color-200 { background-color: #ff00d7; }
.term-fg-color-200 { color: #ff00d7; }
.term-bg-color-201 { background-color: #ff00ff; }
.term-fg-color-201 { color: #ff00ff; }
.term-bg-color-202 { background-color: #ff5f00; }
.term-fg-color-202 { color: #ff5f00; }
.term-bg-color-203 { background-color: #ff5f5f; }
.term-fg-color-203 { color: #ff5f5f; }
.term-bg-color-204 { background-color: #ff5f87; }
.term-fg-color-204 { color: #ff5f87; }
.term-bg-color-205 { background-color: #ff5faf; }
.term-fg-color-205 { color: #ff5faf; }
.term-bg-color-206 { background-color: #ff5fd7; }
.term-fg-color-206 { color: #ff5fd7; }
.term-bg-color-207 { background-color: #ff5fff; }
.term-fg-color-207 { color: #ff5fff; }
.term-bg-color-208 { background-color: #ff8700; }
.term-fg-color-208 { color: #ff8700; }
.term-bg-color-209 { background-color: #ff875f; }
.term-fg-color-209 { color: #ff875f; }
.term-bg-color-210 { background-color: #ff8787; }
.term-fg-color-210 { color: #ff8787; }
.term-bg-color-211 { background-color: #ff87af; }
.term-fg-color-211 { color: #ff87af; }
.term-bg-color-212 { background-color: #ff87d7; }
.term-fg-color-212 { color: #ff87d7; }
.term-bg-color-213 { background-color: #ff87ff; }
.term-fg-color-213 { color: #ff87ff; }
.term-bg-color-214 { background-color: #ffaf00; }
.term-fg-color-214 { color: #ffaf00; }
.term-bg-color-215 { background-color: #ffaf5f; }
.term-fg-color-215 { color: #ffaf5f; }
.term-bg-color-216 { background-color: #ffaf87; }
.term-fg-color-216 { color: #ffaf87; }
.term-bg-color-217 { background-color: #ffafaf; }
.term-fg-color-217 { color: #ffafaf; }
.term-bg-color-218 { background-color: #ffafd7; }
.term-fg-color-218 { color: #ffafd7; }
.term-bg-color-219 { background-color: #ffafff; }
.term-fg-color-219 { color: #ffafff; }
.term-bg-color-220 { background-color: #ffd700; }
.term-fg-color-220 { color: #ffd700; }
.term-bg-color-221 { background-color: #ffd75f; }
.term-fg-color-221 { color: #ffd75f; }
.term-bg-color-222 { background-color: #ffd787; }
.term-fg-color-222 { color: #ffd787; }
.term-bg-color-223 { background-color: #ffd7af; }
.term-fg-color-223 { color: #ffd7af; }
.term-bg-color-224 { background-color: #ffd7d7; }
.term-fg-color-224 { color: #ffd7d7; }
.term-bg-color-225 { background-color: #ffd7ff; }
.term-fg-color-225 { color: #ffd7ff; }
.term-bg-color-226 { background-color: #ffff00; }
.term-fg-color-226 { color: #ffff00; }
.term-bg-color-227 { background-color: #ffff5f; }
.term-fg-color-227 { color: #ffff5f; }
.term-bg-color-228 { background-color: #ffff87; }
.term-fg-color-228 { color: #ffff87; }
.term-bg-color-229 { background-color: #ffffaf; }
.term-fg-color-229 { color: #ffffaf; }
.term-bg-color-230 { background-color: #ffffd7; }
.term-fg-color-230 { color: #ffffd7; }
.term-bg-color-231 { background-color: #ffffff; }
.term-fg-color-231 { color: #ffffff; }
.term-bg-color-232 { background-color: #080808; }
.term-fg-color-232 { color: #080808; }
.term-bg-color-233 { background-color: #121212; }
.term-fg-color-233 { color: #121212; }
.term-bg-color-234 { background-color: #1c1c1c; }
.term-fg-color-234 { color: #1c1c1c; }
.term-bg-color-235 { background-color: #262626; }
.term-fg-color-235 { color: #262626; }
.term-bg-color-236 { background-color: #303030; }
.term-fg-color-236 { color: #303030; }
.term-bg-color-237 { background-color: #3a3a3a; }
.term-fg-color-237 { color: #3a3a3a; }
.term-bg-color-238 { background-color: #444444; }
.term-fg-color-238 { color: #444444; }
.term-bg-color-239 { background-color: #4e4e4e; }
.term-fg-color-239 { color: #4e4e4e; }
.term-bg-color-240 { background-color: #585858; }
.term-fg-color-240 { color: #585858; }
.term-bg-color-241 { background-color: #626262; }
.term-fg-color-241 { color: #626262; }
.term-bg-color-242 { background-color: #6c6c6c; }
.term-fg-color-242 { color: #6c6c6c; }
.term-bg-color-243 { background-color: #767676; }
.term-fg-color-243 { color: #767676; }
.term-bg-color-244 { background-color: #808080; }
.term-fg-color-244 { color: #808080; }
.term-bg-color-245 { background-color: #8a8a8a; }
.term-fg-color-245 { color: #8a8a8a; }
.term-bg-color-246 { background-color: #949494; }
.term-fg-color-246 { color: #949494; }
.term-bg-color-247 { background-color: #9e9e9e; }
.term-fg-color-247 { color: #9e9e9e; }
.term-bg-color-248 { background-color: #a8a8a8; }
.term-fg-color-248 { color: #a8a8a8; }
.term-bg-color-249 { background-color: #b2b2b2; }
.term-fg-color-249 { color: #b2b2b2; }
.term-bg-color-250 { background-color: #bcbcbc; }
.term-fg-color-250 { color: #bcbcbc; }
.term-bg-color-251 { background-color: #c6c6c6; }
.term-fg-color-251 { color: #c6c6c6; }
.term-bg-color-252 { background-color: #d0d0d0; }
.term-fg-color-252 { color: #d0d0d0; }
.term-bg-color-253 { background-color: #dadada; }
.term-fg-color-253 { color: #dadada; }
.term-bg-color-254 { background-color: #e4e4e4; }
.term-fg-color-254 { color: #e4e4e4; }
.term-bg-color-255 { background-color: #eeeeee; }
.term-fg-color-255 { color: #eeeeee; }
.term-bg-color-default { background-color: #000000; }
.term-bg-color-256 { background-color: #000000; }
.term-fg-color-256 { color: #000000; }
.term-fg-color-default { color: #f0f0f0; }
.term-bg-color-257 { background-color: #f0f0f0; }
.term-fg-color-257 { color: #f0f0f0; }
.term-bold { font-weight: bold; }
.term-underline { text-decoration: underline; }
.term-blink { text-decoration: blink; }
.term-hidden { visibility: hidden; }
